@@ -25,12 +25,15 @@ def register():
         account.Configuration,
         account.ConfigurationAssetSequence,
         account.ConfigurationAssetDate,
+        account.ConfigurationAssetFrequency,
+        account.AccountTypeTemplate,
+        account.AccountType,
         account.Move,
         account.Period,
         account.Journal,
         module='account_asset', type_='model')
     Pool.register(
-        purchase.PurchaseLine,
+        purchase.Line,
         module='account_asset', type_='model', depends=['purchase'])
     Pool.register(
         asset.CreateMoves,
