@@ -689,11 +689,18 @@ class Asset(Workflow, ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        names = clause[2].split(' - ', 1)
-        res = [('number', clause[1], names[0])]
-        if len(names) != 1 and names[1]:
-            res.append(('product', clause[1], names[1]))
-        return res
+        domain = []
+        _, operator, value = clause
+        if value is not None:
+            names = value.split(' - ', 1)
+            domain.append(('number', operator, value))
+            if len(names) != 1 and names[1]:
+                domain.append(('product', operator, value))
+            if operator.startswith('!') or operator.startswith('not'):
+                domain.insert(0, 'OR')
+        elif not operator.startswith('!') and not operator.startswith('not'):
+            domain.append(('id', '<', 0))
+        return domain
 
     @classmethod
     def copy(cls, assets, default=None):
